qermit.probabilistic_error_cancellation
=======================================

.. currentmodule:: qermit.probabilistic_error_cancellation.probabilistic_error_cancellation

.. automethod:: qermit.probabilistic_error_cancellation.pec_learning_based.gen_PEC_learning_based_MitEx

.. automethod:: qermit.probabilistic_error_cancellation.pec_learning_based.gen_rebase_to_frames_and_computing

.. automethod:: qermit.probabilistic_error_cancellation.pec_learning_based.gen_run_with_quasi_prob

.. automethod:: qermit.probabilistic_error_cancellation.pec_learning_based.collate_results_task_gen

.. automethod:: qermit.probabilistic_error_cancellation.pec_learning_based.learn_quasi_probs_task_gen

.. automethod:: qermit.probabilistic_error_cancellation.pec_learning_based.gen_get_clifford_training_set

.. automethod:: qermit.probabilistic_error_cancellation.pec_learning_based.gen_label_gates

.. automethod:: qermit.probabilistic_error_cancellation.pec_learning_based.gen_wrap_frame_gates

.. automethod:: qermit.probabilistic_error_cancellation.pec_learning_based.gen_get_noisy_circuits